aboutsummaryrefslogtreecommitdiff
path: root/server.c
diff options
context:
space:
mode:
authorFlavio Cruz <flaviocruz@gmail.com>2016-04-03 02:27:23 +0200
committerSamuel Thibault <samuel.thibault@ens-lyon.org>2016-04-03 10:58:39 +0200
commit2fdebbcabc5416c8b4e895c4a439748050ff1259 (patch)
tree9bac1d474fd11993299503d9caa92862328ab6d8 /server.c
parent7f10b4ed6a557b7a1fd1083939156a3dcf8b377e (diff)
downloadmig-2fdebbcabc5416c8b4e895c4a439748050ff1259.tar.gz
mig-2fdebbcabc5416c8b4e895c4a439748050ff1259.tar.bz2
mig-2fdebbcabc5416c8b4e895c4a439748050ff1259.zip
Use word_size instead of 4.
* server.c: Use word_size and update comments. * type.c: Use word_size to compute padding. * user.c: Use word_size and update comments.
Diffstat (limited to 'server.c')
-rw-r--r--server.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/server.c b/server.c
index 37cb6e0..1d10093 100644
--- a/server.c
+++ b/server.c
@@ -479,7 +479,7 @@ WriteCheckArgSize(FILE *file, const argument_t *arg)
arg->argLongForm ? ".msgtl_header" : "");
}
- if (btype->itTypeSize % 4 != 0)
+ if (btype->itTypeSize % word_size != 0)
fprintf(file, "(");
if (multiplier > 1)
@@ -487,10 +487,10 @@ WriteCheckArgSize(FILE *file, const argument_t *arg)
fprintf(file, "In%dP->%s", arg->argRequestPos, count->argMsgField);
/* If the base type size of the data field isn`t a multiple of 4,
we have to round up. */
- if (btype->itTypeSize % 4 != 0)
- fprintf(file, " + 3) & ~3");
+ if (btype->itTypeSize % word_size != 0)
+ fprintf(file, " + %d) & ~%d", word_size - 1, word_size - 1);
if (ptype->itIndefinite) {
fprintf(file, " : sizeof(%s *)", FetchServerType(btype));
@@ -526,8 +526,8 @@ WriteCheckMsgSize(FILE *file, const argument_t *arg)
boolean_t LastVarArg = arg->argRequestPos+1 == rt->rtNumRequestVar;
/* calculate the actual size in bytes of the data field. note
- that this quantity must be a multiple of four. hence, if
- the base type size isn't a multiple of four, we have to
+ that this quantity must be a multiple of word_size. hence, if
+ the base type size isn't a multiple of word_size, we have to
round up. note also that btype->itNumber must
divide btype->itTypeSize (see itCalculateSizeInfo). */
@@ -1083,7 +1083,7 @@ WriteArgSize(FILE *file, const argument_t *arg)
arg->argLongForm ? ".msgtl_header" : "");
}
- if (bsize % 4 != 0)
+ if (bsize % word_size != 0)
fprintf(file, "(");
if (bsize > 1)
@@ -1096,11 +1096,11 @@ WriteArgSize(FILE *file, const argument_t *arg)
fprintf(file, "%s", count->argVarName);
/*
* If the base type size is not a multiple of sizeof(int) [4],
* we have to round up.
*/
- if (bsize % 4 != 0)
- fprintf(file, " + 3) & ~3");
+ if (bsize % word_size != 0)
+ fprintf(file, " + %d) & ~%d", word_size - 1, word_size - 1);
if (ptype->itIndefinite) {
fprintf(file, " : sizeof(%s *)",
@@ -487,10 +487,10 @@ WriteCheckArgSize(FILE *file, const argument_t *arg)
fprintf(file, "In%dP->%s", arg->argRequestPos, count->argMsgField);
- /* If the base type size of the data field isn`t a multiple of 4,
+ /* If the base type size of the data field isn`t a multiple of word_size,
we have to round up. */
@@ -1096,11 +1096,11 @@ WriteArgSize(FILE *file, const argument_t *arg)
fprintf(file, "%s", count->argVarName);
/*
- * If the base type size is not a multiple of sizeof(int) [4],
+ * If the base type size is not a multiple of word_size,
* we have to round up.
*/